@@ -35,6 +35,8 @@ static int _sequence_nr = 0;
 struct dm_event_handler {
 	char *dso;
 
+	char *dmeventd_path;
+
 	char *dev_name;
 
 	char *uuid;
@@ -47,10 +49,8 @@ struct dm_event_handler {
 
 static void _dm_event_handler_clear_dev_info(struct dm_event_handler *dmevh)
 {
-	if (dmevh->dev_name)
-		dm_free(dmevh->dev_name);
-	if (dmevh->uuid)
-		dm_free(dmevh->uuid);
+	dm_free(dmevh->dev_name);
+	dm_free(dmevh->uuid);
 	dmevh->dev_name = dmevh->uuid = NULL;
 	dmevh->major = dmevh->minor = 0;
 }
@@ -62,6 +62,7 @@ struct dm_event_handler *dm_event_handler_create(void)
 	if (!(dmevh = dm_malloc(sizeof(*dmevh))))
 		return NULL;
 
+	dmevh->dmeventd_path = NULL;
 	dmevh->dso = dmevh->dev_name = dmevh->uuid = NULL;
 	dmevh->major = dmevh->minor = 0;
 	dmevh->mask = 0;
@@ -73,17 +74,30 @@ struct dm_event_handler *dm_event_handler_create(void)
 void dm_event_handler_destroy(struct dm_event_handler *dmevh)
 {
 	_dm_event_handler_clear_dev_info(dmevh);
-	if (dmevh->dso)
-		dm_free(dmevh->dso);
+	dm_free(dmevh->dso);
+	dm_free(dmevh->dmeventd_path);
 	dm_free(dmevh);
 }
 
+int dm_event_handler_set_dmeventd_path(struct dm_event_handler *dmevh, const char *dmeventd_path)
+{
+	if (!dmeventd_path) /* noop */
+		return 0;
+
+	dm_free(dmevh->dmeventd_path);
+
+	dmevh->dmeventd_path = dm_strdup(dmeventd_path);
+	if (!dmevh->dmeventd_path)
+		return -ENOMEM;
+
+	return 0;
+}
+
 int dm_event_handler_set_dso(struct dm_event_handler *dmevh, const char *path)
 {
 	if (!path) /* noop */
 		return 0;
-	if (dmevh->dso)
-		dm_free(dmevh->dso);
+	dm_free(dmevh->dso);
 
 	dmevh->dso = dm_strdup(path);
 	if (!dmevh->dso)
@@ -259,8 +273,7 @@ static int _daemon_read(struct dm_event_fifos *fifos,
 	}
 
 	if (bytes != size) {
-		if (msg->data)
-			dm_free(msg->data);
+		dm_free(msg->data);
 		msg->data = NULL;
 	}
 
@@ -366,8 +379,7 @@ static int _daemon_talk(struct dm_event_fifos *fifos,
 
 	do {
 
-		if (msg->data)
-			dm_free(msg->data);
+		dm_free(msg->data);
 		msg->data = 0;
 
 		if (!_daemon_read(fifos, msg)) {
@@ -393,13 +405,13 @@ static int _daemon_talk(struct dm_event_fifos *fifos,
  *
  * Returns: 1 on success, 0 otherwise
  */
-static int _start_daemon(struct dm_event_fifos *fifos)
+static int _start_daemon(char *dmeventd_path, struct dm_event_fifos *fifos)
 {
 	int pid, ret = 0;
 	int status;
 	struct stat statbuf;
-	char dmeventdpath[] = DMEVENTD_PATH; /* const type for execvp */
-	char * const args[] = { dmeventdpath, NULL };
+	char default_dmeventd_path[] = DMEVENTD_PATH;
+	char *args[] = { dmeventd_path ? : default_dmeventd_path, NULL };
 
 	if (stat(fifos->client_path, &statbuf))
 		goto start_server;
@@ -455,17 +467,19 @@ static int _start_daemon(struct dm_event_fifos *fifos)
 }
 
 /* Initialize client. */
-static int _init_client(struct dm_event_fifos *fifos)
+static int _init_client(char *dmeventd_path, struct dm_event_fifos *fifos)
 {
 	/* FIXME? Is fifo the most suitable method? Why not share
 	   comms/daemon code with something else e.g. multipath? */
 
 	/* init fifos */
 	memset(fifos, 0, sizeof(*fifos));
+
+	/* FIXME Make these either configurable or depend directly on dmeventd_path */
 	fifos->client_path = DM_EVENT_FIFO_CLIENT;
 	fifos->server_path = DM_EVENT_FIFO_SERVER;
 
-	if (!_start_daemon(fifos)) {
+	if (!_start_daemon(dmeventd_path, fifos)) {
 		stack;
 		return 0;
 	}
@@ -550,22 +564,21 @@ failed:
 }
 
 /* Handle the event (de)registration call and return negative error codes. */
-static int _do_event(int cmd, struct dm_event_daemon_message *msg,
+static int _do_event(int cmd, char *dmeventd_path, struct dm_event_daemon_message *msg,
 		     const char *dso_name, const char *dev_name,
 		     enum dm_event_mask evmask, uint32_t timeout)
 {
 	int ret;
 	struct dm_event_fifos fifos;
 
-	if (!_init_client(&fifos)) {
+	if (!_init_client(dmeventd_path, &fifos)) {
 		stack;
 		return -ESRCH;
 	}
 
 	ret = _daemon_talk(&fifos, msg, DM_EVENT_CMD_HELLO, 0, 0, 0, 0);
 
-	if (msg->data)
-		dm_free(msg->data);
+	dm_free(msg->data);
 	msg->data = 0;
 
 	if (!ret)
@@ -592,7 +605,7 @@ int dm_event_register_handler(const struct dm_event_handler *dmevh)
 
 	uuid = dm_task_get_uuid(dmt);
 
-	if ((err = _do_event(DM_EVENT_CMD_REGISTER_FOR_EVENT, &msg,
+	if ((err = _do_event(DM_EVENT_CMD_REGISTER_FOR_EVENT, dmevh->dmeventd_path, &msg,
 			     dmevh->dso, uuid, dmevh->mask, dmevh->timeout)) < 0) {
 		log_error("%s: event registration failed: %s",
 			  dm_task_get_name(dmt),
@@ -600,8 +613,7 @@ int dm_event_register_handler(const struct dm_event_handler *dmevh)
 		ret = 0;
 	}
 
-	if (msg.data)
-		dm_free(msg.data);
+	dm_free(msg.data);
 
 	dm_task_destroy(dmt);
 
@@ -622,7 +634,7 @@ int dm_event_unregister_handler(const struct dm_event_handler *dmevh)
 
 	uuid = dm_task_get_uuid(dmt);
 
-	if ((err = _do_event(DM_EVENT_CMD_UNREGISTER_FOR_EVENT, &msg,
+	if ((err = _do_event(DM_EVENT_CMD_UNREGISTER_FOR_EVENT, dmevh->dmeventd_path, &msg,
 			    dmevh->dso, uuid, dmevh->mask, dmevh->timeout)) < 0) {
 		log_error("%s: event deregistration failed: %s",
 			  dm_task_get_name(dmt),
@@ -630,8 +642,7 @@ int dm_event_unregister_handler(const struct dm_event_handler *dmevh)
 		ret = 0;
 	}
 
-	if (msg.data)
-		dm_free(msg.data);
+	dm_free(msg.data);
 
 	dm_task_destroy(dmt);
 
@@ -698,7 +709,7 @@ int dm_event_get_registered_device(struct dm_event_handler *dmevh, int next)
 	uuid = dm_task_get_uuid(dmt);
 
 	if (!(ret = _do_event(next ? DM_EVENT_CMD_GET_NEXT_REGISTERED_DEVICE :
-			     DM_EVENT_CMD_GET_REGISTERED_DEVICE,
+			     DM_EVENT_CMD_GET_REGISTERED_DEVICE, dmevh->dmeventd_path,
 			      &msg, dmevh->dso, uuid, dmevh->mask, 0))) {
 		/* FIXME this will probably horribly break if we get
 		   ill-formatted reply */
@@ -711,10 +722,8 @@ int dm_event_get_registered_device(struct dm_event_handler *dmevh, int next)
 	dm_task_destroy(dmt);
 	dmt = NULL;
 
-	if (msg.data) {
-		dm_free(msg.data);
-		msg.data = NULL;
-	}
+	dm_free(msg.data);
+	msg.data = NULL;
 
 	_dm_event_handler_clear_dev_info(dmevh);
 	dmevh->uuid = dm_strdup(reply_uuid);
@@ -731,15 +740,11 @@ int dm_event_get_registered_device(struct dm_event_handler *dmevh, int next)
 	dm_event_handler_set_dso(dmevh, reply_dso);
 	dm_event_handler_set_event_mask(dmevh, reply_mask);
 
-	if (reply_dso) {
-		dm_free(reply_dso);
-		reply_dso = NULL;
-	}
+	dm_free(reply_dso);
+	reply_dso = NULL;
 
-	if (reply_uuid) {
-		dm_free(reply_uuid);
-		reply_uuid = NULL;
-	}
+	dm_free(reply_uuid);
+	reply_uuid = NULL;
 
 	dmevh->dev_name = dm_strdup(dm_task_get_name(dmt));
 	if (!dmevh->dev_name) {
@@ -760,12 +765,9 @@ int dm_event_get_registered_device(struct dm_event_handler *dmevh, int next)
 	return ret;
 
  fail:
-	if (msg.data)
-		dm_free(msg.data);
-	if (reply_dso)
-		dm_free(reply_dso);
-	if (reply_uuid)
-		dm_free(reply_uuid);
+	dm_free(msg.data);
+	dm_free(reply_dso);
+	dm_free(reply_uuid);
 	_dm_event_handler_clear_dev_info(dmevh);
 	if (dmt)
 		dm_task_destroy(dmt);
