@@ -145,7 +145,7 @@ struct metadata_area_ops {
 	 * Per location description for logging.
 	 */
 	const char *(*mda_metadata_locn_name) (void *metadata_locn);
-	uint64_t const (*mda_metadata_locn_offset) (void *metadata_locn);
+	uint64_t (*mda_metadata_locn_offset) (void *metadata_locn);
 
 	/*
 	 * Returns number of free sectors in given metadata area.
@@ -416,4 +416,8 @@ int add_pv_to_vg(struct volume_group *vg, const char *pv_name,
 int vg_mark_partial_lvs(struct volume_group *vg);
 int is_mirror_image_removable(struct logical_volume *mimage_lv, void *baton);
 
+uint64_t find_min_mda_size(struct dm_list *mdas);
+uint64_t vg_mda_size(const struct volume_group *vg);
+uint64_t vg_mda_free(const struct volume_group *vg);
+
 #endif
