@@ -14,7 +14,7 @@
 #ifndef _LIB_LVM2APP_H
 #define _LIB_LVM2APP_H
 
-#include "libdevmapper.h"
+#include <libdevmapper.h>
 
 #include <stdint.h>
 
